==> cmsmadesimple-1.5.3.tgz: cms/modules/ModuleManager/lang/ext/cs_CZ.php <==
<?php
$lang['use_at_your_own_risk'] = 'Použijte na vlastn&iacute; nebezpeč&iacute;';
$lang['compatibility_disclaimer'] = 'Moduly zde zobrazen&eacute; přispěli jak v&yacute;voj&aacute;ři CMS, tak nez&aacute;visl&iacute; přispěvatel&eacute;. Negarantujeme, že moduly zde dostupn&eacute; jsou funkčn&iacute;, testovan&eacute; nebo kompatibiln&iacute; s Va&scaron;&iacute;m syst&eacute;mem. Před instalac&iacute; každ&eacute;ho modulu byste si měli přeč&iacute;st informace v n&aacute;povědě a v položce o modulu.';
$lang['notice'] = 'Upozorněn&iacute;';
$lang['general_notice'] = 'Verze zobrazen&aacute; zde reprezentuje posledn&iacute; soubory XML nahran&eacute; do V&aacute;mi zvolen&eacute;ho repozit&aacute;ře (běžně CMS %s). Nemus&iacute; předstatovat posledn&iacute; dostupn&eacute; verze. Možn&aacute; budete cht&iacute;t zobrazit dostupn&aacute; vyd&aacute;n&iacute; ve V&aacute;mi vybran&eacute;m repozit&aacute;ři. Při použ&iacute;t&iacute; v&yacute;choz&iacute;ho repozit&aacute;ře to jde udělat zad&aacute;n&iacute;m jm&eacute;na modulu do vyhled&aacute;vac&iacute;ho boxu na %s a kliknout na tlač&iacute;tko &quot;Soubory&quot;.';
$lang['incompatible'] = 'Nekompatibiln&iacute;';
$lang['prompt_settings'] = 'Nastaven&iacute;';
$lang['prompt_otheroptions'] = 'Jin&eacute; volby';
$lang['reset'] = 'Reset';
$lang['error_permissions'] = '<strong><em>VAROV&Aacute;N&Iacute;:</em></strong> Nedostatečn&aacute; př&iacute;stupov&aacute; pr&aacute;va k adres&aacute;ři pro instalaci modulů. Můžete m&iacute;t tak&eacute; probl&eacute;my s PHP Safe m&oacute;dem.  Ujistěte se pros&iacute;m, že safe m&oacute;d je vypnut&yacute; a že m&aacute;te dostatečn&aacute; pr&aacute;va.';
$lang['error_minimumrepository'] = 'Verze repozit&aacute;ře nen&iacute; kompatibiln&iacute; s t&iacute;mto module managerem';
$lang['prompt_reseturl'] = 'Reset URL na v&yacute;choz&iacute;';
$lang['prompt_resetcache'] = 'Reset lok&aacute;ln&iacute; ke&scaron;e repozit&aacute;řov&yacute;ch dat';
$lang['prompt_dl_chunksize'] = 'Velikost d&aacute;vky ke stažen&iacute; (Kb)';
$lang['text_dl_chunksize'] = 'Maxim&aacute;ln&iacute; velikost dat pro stažen&iacute; ze serveru v jedn&eacute; d&aacute;vce (při instalaci modulu)';
$lang['error_nofilesize'] = 'Nezad&aacute;n parametr velikost souboru';
$lang['error_nofilename'] = 'Nezad&aacute;n parametr jm&eacute;no souboru';
$lang['error_checksum'] = 'Chyba kontroln&iacute;ho součtu. Toto pravděpodobně indikuje po&scaron;kozen&yacute; souboru, buď  když byl přen&aacute;&scaron;en do repozit&aacute;ře, nebo na cestě při stahov&aacute;n&iacute; do va&scaron;eho poč&iacute;tače.';
$lang['cantdownload'] = 'Nelze st&aacute;hnout';
$lang['download'] = 'St&aacute;hnout';
$lang['error_moduleinstallfailed'] = 'Instalace modulu selhala';
$lang['error_connectnomodules'] = 'Ačkoliv bylo &uacute;&scaron;pě&scaron;ně vytvořeno spojen&iacute; k zadan&eacute;mu repozit&aacute;ři, vypad&aacute; to, že tento repozit&aacute;ř zat&iacute;m nesd&iacute;l&iacute; ž&aacute;dn&eacute; moduly';
$lang['submit'] = 'Odeslat';
$lang['text_repository_url'] = 'URL mus&iacute; b&yacute;t ve form&aacute;tu http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
$lang['prompt_repository_url'] = 'URL repozit&aacute;ře modulů:';
$lang['availmodules'] = 'Dostupn&eacute; moduly';
$lang['preferences'] = 'Nastaven&iacute;';
$lang['preferencessaved'] = 'Nastaven&iacute; uložena';
$lang['repositorycount'] = 'Moduly nalezen&eacute; v repozit&aacute;ři';
$lang['instcount'] = 'Nainstalovan&eacute; moduly';
$lang['availablemodules'] = 'Aktu&aacute;ln&iacute; status modulů dostupn&yacute;ch z aktu&aacute;ln&iacute;ho repozit&aacute;ře';
$lang['helptxt'] = 'N&aacute;pověda';
$lang['abouttxt'] = 'O';
$lang['xmltext'] = 'XML soubor';
$lang['nametext'] = 'Jm&eacute;no modulu';
$lang['vertext'] = 'Verze';
$lang['sizetext'] = 'Velikost';
$lang['statustext'] = 'Stav';
$lang['uptodate'] = 'Aktu&aacute;ln&iacute;';
$lang['install'] = 'instalovat';
$lang['newerversion'] = 'Nověj&scaron;&iacute; verze nainstalov&aacute;na';
$lang['onlynewesttext'] = 'Zobrazovat pouze nejnověj&scaron;&iacute; verze';
$lang['upgrade'] = 'Dostupn&aacute; aktualizace';
$lang['error_nosoapconnect'] = 'Nelze se připojit k SOAP serveru';
$lang['error_soaperror'] = 'SOAP Probl&eacute;m';
$lang['error_norepositoryurl'] = 'URL adresa repozit&aacute;ře modulu nebyla dosud zad&aacute;na';
$lang['friendlyname'] = 'Spr&aacute;vce modulů';
$lang['postinstall'] = 'Poinstalačn&iacute; zpr&aacute;va, (např., Nastavte pr&aacute;va &quot;&quot; pro použit&iacute; tohoto modulu!)';
$lang['postuninstall'] = 'Poodinstalačn&iacute; zpr&aacute;va, např., &quot;Curses! Foiled Again!&quot;';
$lang['really_uninstall'] = 'Opravdu chcete odinstalovat tento modul?';
$lang['uninstalled'] = 'Modul odinstalov&aacute;n.';
$lang['installed'] = 'Modul verze %s nainstalov&aacute;n.';
$lang['upgraded'] = 'Module pov&yacute;&scaron;en na verzi %s.';
$lang['moddescription'] = 'Klient pro ModuleRepository, tento modul umožňuje n&aacute;hled a instalaci modulů ze vzd&aacute;len&yacute;ch serverů bez potřeby stahov&aacute;n&iacute; přes ftp nebo rozbalov&aacute;n&iacute; archivů.  XML soubory modulů jsou staženy pomoc&iacute; SOAP, zkontrolov&aacute;na integrita a pot&eacute; automaticky rozbalen.';
$lang['error'] = 'Chyba!';
$lang['admindescription'] = 'N&aacute;stroj pro stahov&aacute;n&iacute; a instalov&aacute;n&iacute; modulů ze vzd&aacute;len&yacute;ch serverů.';
$lang['accessdenied'] = 'Př&iacute;stup zak&aacute;z&aacute;n. Ověřte pros&iacute;m sv&aacute; opr&aacute;vněn&iacute;.';
$lang['changelog'] = '<ul>
<li>Version 1.0. 10 January 2006. Initial Release.</li>
<li>Version 1.1. July, 2006. Released with the 1.0- beta</li>
<li>Version 1.1.1 August, 2006.  Require 1.0.1 of nuSOAP</li>
<li>Version 1.1.2 September, 2006.  Fixed a mistake that resulted in upgrade not not working at all</li>
<li>Version 1.1.3 September, 2006.
  <ul>
  <li>Bumped minimum CMS Version to 1.0</li>
  <li>Now use 1 request to get the complete list of modules from the repository</li>
  <li>Added some missing lang strings</li>
  <li>Added the ability to reset the local cache of repository information</li>
  <li>Added the ability to restore the repository url to factory defaults</li>
  </ul>
</li>
<li>Version 1.1.4 February, 2007.  Now handles the safe mode check, and disables upgrading or installing modules if the permissions are wrong.</li>
<li>Version 1.1.5 September, 2007. New preference to make only latest module version show. Added nice message after saving preferences</li>
</li>
<li>Version 1.1.6 May, 2008. Now show if available modules are incompatible with the current CMS_VERSION.</li>
</li>
<li>Version 1.2 June, 2008.<br/>
This version should reduce the memory requirements of this module, and trade it off for performance on the server, and mroe requests to the server.
   <ul>
    <li>Bumped Minimum CMS Version to 1.3</li>
    <li>Bumped Minimum repository version to 1.1</li>
    <li>Get rid of all of the session stuff</li>
    <li>Add support for requesting modules beginning with a prefix (usually a single letter)</li>
    <li>Add support for requestion only the newest versions of the modules</li>
   </ul>
</li>
<li>Version 1.2.1 August, 2008.<br/>
Added a warning message to the top of the admin display.
</li>
</ul>';
$lang['help'] = '<h3>Co děl&aacute; tento modul?</h3>
<p>Klient pro ModuleRepository, tento modul dovoluje n&aacute;hled a instalaci modulů ze vzd&aacute;len&yacute;ch str&aacute;nek bez potřeby stahov&aacute;n&iacute; z ftp a rozbalov&aacute;n&iacute;.  XML soubory modulu jsou stahov&aacute;ny pomoc&iacute; SOAP, je zkontrolov&aacute;na integrita a pot&eacute; jsou automaticky rozbaleny.</p>
<h3>Jak se použ&iacute;v&aacute;</h3>
<p>Pro použ&iacute;v&aacute;n&iacute; tohoto modulu potřebujete &#039;Modify Modules&#039; opr&aacute;vněn&iacute; a tak&eacute; kompletn&iacute; a plnou cestu URL do &#039;Module Repository&#039;.  Tato cesta lze zadat na str&aacute;nce &#039;Administrace&#039; --> &#039;Glob&aacute;ln&iacute; nastaven&iacute;&#039; .</p><br/>
<p>Rozhran&iacute; pro tento modul naleznete v menu &#039;Roz&scaron;&iacute;řen&iacute;&#039;.  Při v&yacute;běru tohoto modulu, &#039;Module Repository&#039; instalace automaticky st&aacute;hne seznam dostupn&yacute;ch xml modulů.  Tento seznam je porovn&aacute;n s aktu&aacute;lně instalovan&yacute;mi moduly a zobrazena v&yacute;sledn&aacute; str&aacute;nka.  Zde uvid&iacute;te popis, n&aacute;povědu a informace o modulu bez jeho fyzick&eacute; instalace.  Lze tak&eacute; vybrat aktualizace nebo instalace modulů.</p>
<h3>Podpora</h3>
<p>Tento program je dod&aacute;van jak je, dle licence GPL. Pro pln&eacute; odvol&aacute;n&iacute; čtěte pros&iacute;m text licence.</p>
<h3>Copyright a Licence</h3>
<p>Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
<p>Tento modul byl vyd&aacute;n pod <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. Mus&iacute;te souhlasit s touto licenc&iacute; před použ&iacute;t&iacute;m modulu.</p>';
$lang['utma'] = '156861353.4545864025444168000.1227726513.1235876853.1235894120.23';
$lang['utmz'] = '156861353.1235854022.19.6.utmccn=(referral)|utmcsr=miditower|utmcct=/cms/admin/listmodules.php|utmcmd=referral';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.6.4.tgz: cms/modules/ModuleManager/lang/ext/cs_CZ.php <==
<?php
$lang['available_updates'] = 'Moduly s dostupnou aktualizac&iacute;';
$lang['all_modules_up_to_date'] = 'Nejsou dostupn&eacute; nověj&scaron;&iacute; verze modulů v repozit&aacute;ři';
$lang['error_module_object'] = 'Chyba: nelze z&iacute;skat instanci modulu %s';
$lang['error_nomatchingmodules'] = 'Chyba: nelze naj&iacute;t ž&aacute;dn&yacute; odpov&iacute;daj&iacute;c&iacute; modul v repozit&aacute;ři';
$lang['error_nomodules'] = 'Chyba: nelze st&aacute;hnout seznam nainstalovan&yacute;ch modulů';
$lang['upgrade_available'] = 'Dostupn&aacute; nověj&scaron;&iacute; verze (%s), nyn&iacute; m&aacute;te (%s)';
$lang['newversions'] = 'Dostupn&eacute; aktualizace';
$lang['error_depends'] = 'Jedna nebo v&iacute;ce z&aacute;vislost&iacute; nen&iacute; nainstalov&aacute;no. Je třeba nejdř&iacute;ve nainstalovat z&aacute;vislosti';
$lang['msg_nodependencies'] = 'Soubor nem&aacute; uvedeny ž&aacute;dn&eacute; z&aacute;vislosti';
$lang['dependstxt'] = 'Z&aacute;vislosti';
$lang['use_at_your_own_risk'] = 'Použijte na vlastn&iacute; nebezpeč&iacute;';
$lang['compatibility_disclaimer'] = 'Moduly zde zobrazen&eacute; přispěli jak v&yacute;voj&aacute;ři CMS, tak nez&aacute;visl&iacute; přispěvatel&eacute;. Negarantujeme, že moduly zde dostupn&eacute; jsou funkčn&iacute;, testovan&eacute; nebo kompatibiln&iacute; s Va&scaron;&iacute;m syst&eacute;mem. Před instalac&iacute; každ&eacute;ho modulu byste si měli přeč&iacute;st informace v n&aacute;povědě a v položce o modulu.';
$lang['notice'] = 'Upozorněn&iacute;';
$lang['general_notice'] = 'Verze zobrazen&aacute; zde reprezentuje posledn&iacute; soubory XML nahran&eacute; do V&aacute;mi zvolen&eacute;ho repozit&aacute;ře (běžně CMS %s). Nemus&iacute; představovat posledn&iacute; dostupn&eacute; verze. Možn&aacute; budete cht&iacute;t zobrazit dostupn&aacute; vyd&aacute;n&iacute; ve V&aacute;mi vybran&eacute;m repozit&aacute;ři. Při použit&iacute; v&yacute;choz&iacute;ho repozit&aacute;ře to jde udělat zad&aacute;n&iacute;m jm&eacute;na modulu do vyhled&aacute;vac&iacute;ho boxu na %s a kliknout na tlač&iacute;tko &quot;Soubory&quot;.';
$lang['incompatible'] = 'Nekompatibiln&iacute;';
$lang['prompt_settings'] = 'Nastaven&iacute;';
$lang['prompt_otheroptions'] = 'Jin&eacute; volby';
$lang['reset'] = 'Reset';
$lang['error_permissions'] = '<strong><em>VAROV&Aacute;N&Iacute;:</em></strong> Nedostatečn&aacute; př&iacute;stupov&aacute; pr&aacute;va k adres&aacute;ři pro instalaci modulů. Můžete m&iacute;t tak&eacute; probl&eacute;my s PHP Safe m&oacute;dem.  Ujistěte se pros&iacute;m, že safe m&oacute;d je vypnut&yacute; a že m&aacute;te dostatečn&aacute; pr&aacute;va.';
$lang['error_minimumrepository'] = 'Verze repozit&aacute;ře nen&iacute; kompatibiln&iacute; s t&iacute;mto module managerem';
$lang['prompt_reseturl'] = 'Reset URL na v&yacute;choz&iacute;';
$lang['prompt_resetcache'] = 'Reset lok&aacute;ln&iacute; ke&scaron;e repozit&aacute;řov&yacute;ch dat';
$lang['prompt_dl_chunksize'] = 'Velikost d&aacute;vky ke stažen&iacute; (Kb)';
$lang['text_dl_chunksize'] = 'Maxim&aacute;ln&iacute; velikost dat pro stažen&iacute; ze serveru v jedn&eacute; d&aacute;vce (při instalaci modulu)';
$lang['error_nofilesize'] = 'Nezad&aacute;n parametr velikost souboru';
$lang['error_nofilename'] = 'Nezad&aacute;n parametr jm&eacute;no souboru';
$lang['error_checksum'] = 'Chyba kontroln&iacute;ho součtu. Toto pravděpodobně indikuje po&scaron;kozen&yacute; souboru, buď  když byl přen&aacute;&scaron;en do repozit&aacute;ře, nebo na cestě při stahov&aacute;n&iacute; do va&scaron;eho poč&iacute;tače.';
$lang['cantdownload'] = 'Nelze st&aacute;hnout';
$lang['download'] = 'St&aacute;hnout';
$lang['error_moduleinstallfailed'] = 'Instalace modulu selhala';
$lang['error_connectnomodules'] = 'Ačkoliv bylo &uacute;spě&scaron;ně vytvořeno spojen&iacute; k zadan&eacute;mu repozit&aacute;ři, vypad&aacute; to, že tento repozit&aacute;ř zat&iacute;m nesd&iacute;l&iacute; ž&aacute;dn&eacute; moduly';
$lang['submit'] = 'Odeslat';
$lang['text_repository_url'] = 'URL mus&iacute; b&yacute;t ve form&aacute;tu http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
$lang['prompt_repository_url'] = 'URL repozit&aacute;ře modulů:';
$lang['availmodules'] = 'Dostupn&eacute; moduly';
$lang['preferences'] = 'Nastaven&iacute;';
$lang['preferencessaved'] = 'Nastaven&iacute; uložena';
$lang['repositorycount'] = 'Moduly nalezen&eacute; v repozit&aacute;ři';
$lang['instcount'] = 'Nainstalovan&eacute; moduly';
$lang['availablemodules'] = 'Aktu&aacute;ln&iacute; status modulů dostupn&yacute;ch z aktu&aacute;ln&iacute;ho repozit&aacute;ře';
$lang['helptxt'] = 'N&aacute;pověda';
$lang['abouttxt'] = 'O';
$lang['xmltext'] = 'XML soubor';
$lang['nametext'] = 'Jm&eacute;no modulu';
$lang['vertext'] = 'Verze';
$lang['sizetext'] = 'Velikost';
$lang['statustext'] = 'Stav';
$lang['uptodate'] = 'Aktu&aacute;ln&iacute;';
$lang['install'] = 'instalovat';
$lang['newerversion'] = 'Nověj&scaron;&iacute; verze nainstalov&aacute;na';
$lang['onlynewesttext'] = 'Zobrazovat pouze nejnověj&scaron;&iacute; verze';
$lang['upgrade'] = 'Dostupn&aacute; aktualizace';
$lang['error_nosoapconnect'] = 'Nelze se připojit k SOAP serveru';
$lang['error_soaperror'] = 'SOAP Probl&eacute;m';
$lang['error_norepositoryurl'] = 'URL adresa repozit&aacute;ře modulu nebyla dosud zad&aacute;na';
$lang['friendlyname'] = 'Spr&aacute;vce modulů';
$lang['postinstall'] = 'Poinstalačn&iacute; zpr&aacute;va, (např., Nastavte pr&aacute;va &quot;&quot; pro použit&iacute; tohoto modulu!)';
$lang['postuninstall'] = 'Poodinstalačn&iacute; zpr&aacute;va, např., &quot;Curses! Foiled Again!&quot;';
$lang['really_uninstall'] = 'Opravdu chcete odinstalovat tento modul?';
$lang['uninstalled'] = 'Modul odinstalov&aacute;n.';
$lang['installed'] = 'Modul verze %s nainstalov&aacute;n.';
$lang['upgraded'] = 'Module pov&yacute;&scaron;en na verzi %s.';
$lang['moddescription'] = 'Klient pro ModuleRepository, tento modul umožňuje n&aacute;hled a instalaci modulů ze vzd&aacute;len&yacute;ch serverů bez potřeby stahov&aacute;n&iacute; přes ftp nebo rozbalov&aacute;n&iacute; archivů.  XML soubory modulů jsou staženy pomoc&iacute; SOAP, zkontrolov&aacute;na integrita a pot&eacute; automaticky rozbalen.';
$lang['error'] = 'Chyba!';
$lang['admindescription'] = 'N&aacute;stroj pro stahov&aacute;n&iacute; a instalov&aacute;n&iacute; modulů ze vzd&aacute;len&yacute;ch serverů.';
$lang['accessdenied'] = 'Př&iacute;stup zak&aacute;z&aacute;n. Ověřte pros&iacute;m sv&aacute; opr&aacute;vněn&iacute;.';
$lang['changelog'] = '<ul>
<li>Version 1.0. 10 January 2006. Initial Release.</li>
<li>Version 1.1. July, 2006. Released with the 1.0- beta</li>
<li>Version 1.1.1 August, 2006.  Require 1.0.1 of nuSOAP</li>
<li>Version 1.1.2 September, 2006.  Fixed a mistake that resulted in upgrade not not working at all</li>
<li>Version 1.1.3 September, 2006.
  <ul>
  <li>Bumped minimum CMS Version to 1.0</li>
  <li>Now use 1 request to get the complete list of modules from the repository</li>
  <li>Added some missing lang strings</li>
  <li>Added the ability to reset the local cache of repository information</li>
  <li>Added the ability to restore the repository url to factory defaults</li>
  </ul>
</li>
<li>Version 1.1.4 February, 2007.  Now handles the safe mode check, and disables upgrading or installing modules if the permissions are wrong.</li>
<li>Version 1.1.5 September, 2007. New preference to make only latest module version show. Added nice message after saving preferences</li>
</li>
<li>Version 1.1.6 May, 2008. Now show if available modules are incompatible with the current CMS_VERSION.</li>
</li>
<li>Version 1.2 June, 2008.<br/>
This version should reduce the memory requirements of this module, and trade it off for performance on the server, and mroe requests to the server.
   <ul>
    <li>Bumped Minimum CMS Version to 1.3</li>
    <li>Bumped Minimum repository version to 1.1</li>
    <li>Get rid of all of the session stuff</li>
    <li>Add support for requesting modules beginning with a prefix (usually a single letter)</li>
    <li>Add support for requestion only the newest versions of the modules</li>
   </ul>
</li>
<li>Version 1.2.1 August, 2008.<br/>
Added a warning message to the top of the admin display.
</li>
</ul>';
$lang['help'] = '<h3>Co děl&aacute; tento modul?</h3>
<p>Klient pro ModuleRepository, tento modul dovoluje n&aacute;hled a instalaci modulů ze vzd&aacute;len&yacute;ch str&aacute;nek bez potřeby stahov&aacute;n&iacute; z ftp a rozbalov&aacute;n&iacute;.  XML soubory modulu jsou stahov&aacute;ny pomoc&iacute; SOAP, je zkontrolov&aacute;na integrita a pot&eacute; jsou automaticky rozbaleny.</p>
<h3>Jak se použ&iacute;v&aacute;</h3>
<p>Pro použ&iacute;v&aacute;n&iacute; tohoto modulu potřebujete &#039;Modify Modules&#039; opr&aacute;vněn&iacute; a tak&eacute; kompletn&iacute; a plnou cestu URL do &#039;Module Repository&#039;.  Tato cesta lze zadat na str&aacute;nce &#039;Administrace&#039; --> &#039;Glob&aacute;ln&iacute; nastaven&iacute;&#039; .</p><br/>
<p>Rozhran&iacute; pro tento modul naleznete v menu &#039;Roz&scaron;&iacute;řen&iacute;&#039;.  Při v&yacute;běru tohoto modulu, &#039;Module Repository&#039; instalace automaticky st&aacute;hne seznam dostupn&yacute;ch xml modulů.  Tento seznam je porovn&aacute;n s aktu&aacute;lně instalovan&yacute;mi moduly a zobrazena v&yacute;sledn&aacute; str&aacute;nka.  Zde uvid&iacute;te popis, n&aacute;povědu a informace o modulu bez jeho fyzick&eacute; instalace.  Lze tak&eacute; vybrat aktualizace nebo instalace modulů.</p>
<h3>Podpora</h3>
<p>Tento program je dod&aacute;v&aacute;n jak je, dle licence GPL. Pro pln&eacute; odvol&aacute;n&iacute; čtěte pros&iacute;m text licence.</p>
<h3>Copyright a Licence</h3>
<p>Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
<p>Tento modul byl vyd&aacute;n pod <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. Mus&iacute;te souhlasit s touto licenc&iacute; před použit&iacute;m modulu.</p>';
$lang['utma'] = '156861353.3769824904990279700.1249913289.1249913289.1249913289.1';
$lang['utmb'] = '156861353.1.10.1249913289';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1249913289.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['qca'] = '1229762881-19854751-99654968';
$lang['qcb'] = '1368372279';
?>
